require 'sinatra/base'
require 'sinatra/content_for'

module Rackprof
  class Web < Sinatra::Base
    helpers Sinatra::ContentFor

    set :root, File.expand_path(File.dirname(__FILE__) + '/templates')
    set :public_folder, proc { "#{root}/assets" }
    set :views, proc { "#{root}/views" }

    helpers do
      def active_class(path)
        'active' if @env['PATH_INFO'] == path
      end
    end

    get '/' do
      GCNotify.instance.start
      erb :index
    end

    get '/gc_stream', provides: 'text/event-stream' do
      stream :keep_open do |out|
        observer = GCObserver.new(out)
        GCNotify.instance.add_observer(observer)
        out.callback { GCNotify.instance.delete_observer(observer) }
      end
    end

    get '/request' do
      erb :request
    end

    get '/request_stream', provides: 'text/event-stream' do
      stream :keep_open do |out|
        observer = RequestObserver.new(out)
        RequestNotify.instance.add_observer(observer)
        out.callback { RequestNotify.instance.delete_observer(observer) }
      end
    end
  end
end
